## Are you reporting a feature request or a bug?

<!--
Before reporting your issue make sure there are no duplicates already reported.

Please **do not report security issues here**, use the contact form at https://ckeditor.com/contact/ instead.

Replace this comment with your issue type: Bug / Feature request / Other, please explain.
-->

## Provide detailed reproduction steps (if any)

1. …
2. …
3. …

### Expected result

*What is the expected result of the above steps?*

### Actual result

*What is the actual result of the above steps?*

## Other details

* Browser: …
* OS: …
* CKEditor version: …
* Installed CKEditor plugins: …
